package com.web.config;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.module.SimpleModule;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.RequestUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.converter.HttpMessageConverter;
import org.springframework.http.converter.json.MappingJackson2HttpMessageConverter;
import org.springframework.web.multipart.support.StandardMultipartHttpServletRequest;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;
import org.springframework.web.servlet.handler.HandlerInterceptorAdapter;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

@Configuration
public class AuthConfig implements WebMvcConfigurer {

	private static Logger log = LoggerFactory.getLogger(AuthConfig.class);

	@Resource
	private UserCenter userCenter;

	/**
	 * 获取配置文件debug变量
	 */
	@Value("${debug}")
	private boolean debug = false;

	/**
	 * 解决18位long类型数据转json失去精度问题
	 * @param converters
	 */
	@Override
	public void configureMessageConverters(List<HttpMessageConverter<?>> converters){
		MappingJackson2HttpMessageConverter jsonConverter = new MappingJackson2HttpMessageConverter();

		ObjectMapper objectMapper = jsonConverter.getObjectMapper();
		SimpleModule simpleModule = new SimpleModule();
		simpleModule.addSerializer(Long.class, ToStringSerializer.instance);
		simpleModule.addSerializer(Long.TYPE, ToStringSerializer.instance);
		objectMapper.registerModule(simpleModule);

		converters.add(jsonConverter);
	}

	public void addInterceptors(InterceptorRegistry registry) {
	      registry.addInterceptor(new HandlerInterceptorAdapter() {

	          @Override
	          public boolean preHandle(HttpServletRequest request, HttpServletResponse response,
                                       Object handler) throws Exception {
	        	  if(debug){
	        		  return true;
	        	  }
	        	  String token = request.getHeader("Authorization");
	        	  if (StringUtils.isNotBlank(token)) {
					  if(userCenter.isLogin(request) == true) {
						  return true;
					  }
				  }
				  log.error("the user is not logged in,remoteAddr:"+ RequestUtils.getIpAddress(request)+",requestUrl:"+request.getRequestURL());
				  response.setStatus(401);
				  return false;
	          }
	      })
	      .addPathPatterns("/**")
	      .excludePathPatterns("/swagger-resources/**")
	      .excludePathPatterns("/**/api-docs")
	      .excludePathPatterns("/**/springfox-swagger-ui/**")
	      .excludePathPatterns("/**/swagger-ui.html")
	      .excludePathPatterns("/login/*")
	      .excludePathPatterns("/sms/*")
	      ;
	  }
}
