package com.web.controller;

import com.alibaba.fastjson.JSONObject;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.MemberValidateUtil;
import com.hai.common.utils.RedisUtil;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.enum_type.LoginPlatform;
import com.hai.enum_type.RedisFileFolder;
import com.hai.model.HighUserModel;
import com.hai.model.ResponseData;
import com.hai.model.UserInfoModel;
import com.hai.service.HighUserService;
import com.web.type.LoginType;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;

/**
 * @className: CoresController
 * @author: HuRui
 * @date: 2022/10/21
 **/

@Controller
@RequestMapping(value = "/cores")
@Api(value = "用户核心业务")
public class CoresController {

    private static Logger log = LoggerFactory.getLogger(CoresController.class);

    @Resource
    private RedisUtil redisUtil;

    @Resource
    private HighUserService userService;

    @Resource
    private UserCenter userCenter;

    @RequestMapping(value = "/outLogin", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "退出登录")
    public ResponseData outLogin(HttpServletRequest request, HttpServletResponse response) {
        try {
            HighUserModel userInfoModel = userCenter.getSessionModel(HighUserModel.class);
            if (userInfoModel == null) {
                log.error("CoresController --> outLogin() error!", "用户身份错误或已过期");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.SEC_USER_EXPIRED, "");
            }
            userCenter.remove(request, response);
            return ResponseMsgUtil.success("退出登录成功");

        } catch (Exception e) {
            log.error("CoresController --> outLogin() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
